LogRecordExt extension

Extension on LogRecord to add formatting helpers.

These helpers depend on stack_trace_util.dart which is implementation code in chirp, not part of chirp_

on

Properties

callerInfo StackFrameInfo?

Available on LogRecord, provided by the LogRecordExt extension

Extracts caller info from this record's stack trace
no setter
formattedTime String

Available on LogRecord, provided by the LogRecordExt extension

Returns formatted time string like "HH:mm:ss.mmm"
no setter
instanceHash int?

Available on LogRecord, provided by the LogRecordExt extension

Returns the identity hash code of the instance, if present.
no setter

Methods

instanceLabel() String?

Available on LogRecord, provided by the LogRecordExt extension

Returns a formatted instance identifier like "ClassName@a1b2"