BracketedTimestamp class
Renders a timestamp in brackets: "HH:mm:ss.mmm".
Use this to show a secondary timestamp (e.g., wall-clock time) that should be visually distinct from the primary timestamp.
Example output: [10:30:45.123]
Constructors
- BracketedTimestamp(DateTime date)
-
Renders a timestamp in brackets: "
HH:mm:ss.mmm".
Properties
-
allAncestors
→ Iterable<
LogSpan> -
Returns all ancestors from parent to root.
no setterinherited
-
allChildren
→ Iterable<
LogSpan> -
All direct children of this span.
no setterinherited
-
allDescendants
→ Iterable<
LogSpan> -
Returns all descendants (including self) in pre-order.
no setterinherited
- date → DateTime
-
The DateTime to extract the time from.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent → LogSpan?
-
Parent span in the tree, or null if this is the root.
no setterinherited
- root → LogSpan
-
Returns the root span of the tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → LogSpan -
Builds this span into another span, or returns itself if already terminal.
override
-
findAll<
T extends LogSpan> () → Iterable< T> -
Finds all descendants (including self) of type
T.inherited -
findFirst<
T extends LogSpan> () → T? -
Finds the first descendant (including self) of type
T.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → bool -
Removes this span from its parent.
inherited
-
render(
ConsoleMessageBuffer buffer) → void -
Renders this span to the
buffer.inherited -
replaceWith(
LogSpan newSpan) → bool -
Replaces this span in its parent with
newSpan.inherited -
toString(
) → String -
A string representation of this object.
override
-
wrap(
LogSpan wrapper(LogSpan child)) → void -
Wraps this span with a wrapper span.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited