keyValueSeparatorBuilder property
Factory to create the span rendered between the key and value.
Defaults to creating PlainText(': ').
Implementation
final LogSpan Function() keyValueSeparatorBuilder;
Factory to create the span rendered between the key and value.
Defaults to creating PlainText(': ').
final LogSpan Function() keyValueSeparatorBuilder;