MethodName constructor

MethodName(
  1. String name
)

Renders the method name where the log call originated.

Useful for understanding the call context without looking at stack traces.

Example output: processOrder, handleRequest

Implementation

MethodName(this.name);