MultiChildSpan class abstract

Base class for spans that have multiple ordered children.

Examples: SpanSequence.

Inheritance
Implementers
Annotations
  • @experimental

Constructors

MultiChildSpan({List<LogSpan>? children})
Creates a multi child span with optional initial children.

Properties

allAncestors Iterable<LogSpan>
Returns all ancestors from parent to root.
no setterinherited
allChildren Iterable<LogSpan>
All direct children of this span.
no setteroverride
allDescendants Iterable<LogSpan>
Returns all descendants (including self) in pre-order.
no setterinherited
children List<LogSpan>
Read-only view of children.
no setter
hashCode int
The hash code for this object.
no setterinherited
parent LogSpan?
Parent span in the tree, or null if this is the root.
no setterinherited
root LogSpan
Returns the root span of the tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addChild(LogSpan child) → void
Adds child as the last child.
build() LogSpan
Builds this span into another span, or returns itself if already terminal.
inherited
findAll<T extends LogSpan>() Iterable<T>
Finds all descendants (including self) of type T.
inherited
findFirst<T extends LogSpan>() → T?
Finds the first descendant (including self) of type T.
inherited
indexOf(LogSpan child) int
Gets the index of child in this span's children.
insertChild(int index, LogSpan child) → void
Inserts child at index.
nextSiblingOf(LogSpan child) LogSpan?
Gets the next sibling of child, or null if last.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previousSiblingOf(LogSpan child) LogSpan?
Gets the previous sibling of child, or null if first.
remove() bool
Removes this span from its parent.
override
render(ConsoleMessageBuffer buffer) → void
Renders this span to the buffer.
inherited
replaceWith(LogSpan newSpan) bool
Replaces this span in its parent with newSpan.
override
toString() String
A string representation of this object.
inherited
wrap(LogSpan wrapper(LogSpan child)) → void
Wraps this span with a wrapper span.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited