NewLine constructor
NewLine()
Renders a line break (\n).
Use to separate log output across multiple lines, such as between the main message and a stack trace.
Implementation
NewLine();
Renders a line break (\n).
Use to separate log output across multiple lines, such as between the main message and a stack trace.
NewLine();