SpanFormatOptions class

Format options that include span transformers for SpanBasedFormatter.

This allows per-log customization of the span tree, enabling features like:

  • Wrapping specific logs in borders
  • Adding custom decorations to important messages
  • Removing or replacing spans for specific log entries

Example

Chirp.info(
  'Important message',
  formatOptions: [
    SpanFormatOptions(
      spanTransformers: [
        (span, record) => span.wrap(Bordered()),
      ],
    ),
  ],
);
Inheritance
Annotations
  • @experimental

Constructors

SpanFormatOptions({List<SpanTransformer> spanTransformers = const []})
Creates span format options with optional spanTransformers.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spanTransformers List<SpanTransformer>
Additional span transformers to apply for this specific log entry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited