spanTransformers property
Additional span transformers to apply for this specific log entry.
These transformers are applied after the formatter's default transformers.
Implementation
final List<SpanTransformer> spanTransformers;
Additional span transformers to apply for this specific log entry.
These transformers are applied after the formatter's default transformers.
final List<SpanTransformer> spanTransformers;