Surrounded constructor
Creates a surrounded span with optional prefix, child, and suffix.
Implementation
Surrounded({LogSpan? prefix, LogSpan? child, LogSpan? suffix}) {
this.prefix = prefix;
this.child = child;
this.suffix = suffix;
}
Creates a surrounded span with optional prefix, child, and suffix.
Surrounded({LogSpan? prefix, LogSpan? child, LogSpan? suffix}) {
this.prefix = prefix;
this.child = child;
this.suffix = suffix;
}