BoxBorderChars class
Characters for drawing box borders.
Provides predefined border styles: single, double, rounded, heavy, and ascii.
- Annotations
-
- @experimental
Constructors
Properties
- bottomLeft → String
-
The character for the bottom-left corner.
final
- bottomRight → String
-
The character for the bottom-right corner.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontal → String
-
The character for horizontal lines.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topLeft → String
-
The character for the top-left corner.
final
- topRight → String
-
The character for the top-right corner.
final
- vertical → String
-
The character for vertical lines.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromStyle(
BoxBorderStyle style) → BoxBorderChars -
Returns the BoxBorderChars for the given
style.
Constants
- ascii → const BoxBorderChars
- ASCII-only box characters (- | + + + +) for maximum compatibility.
- double → const BoxBorderChars
- Double-line box drawing characters (═ ║ ╔ ╗ ╚ ╝).
- heavy → const BoxBorderChars
- Heavy/thick box drawing characters (━ ┃ ┏ ┓ ┗ ┛).
- rounded → const BoxBorderChars
- Rounded corner box drawing characters (─ │ ╭ ╮ ╰ ╯).
- single → const BoxBorderChars
- Single-line box drawing characters (─ │ ┌ ┐ └ ┘).